==> igniteui-react-charts-16.6.4.tgz: package/ES2015/igr-scatter-polygon-series.js <==
import { Style } from "igniteui-react-core/ES2015/igr-style";
import { MarkerType_$type } from "./MarkerType";
import { CollisionAvoidanceType_$type } from "./CollisionAvoidanceType";
import { IgrShapeSeriesBase } from "./igr-shape-series-base";
import { ScatterPolygonSeries } from "./ScatterPolygonSeries";
import { ensureEnum, brushToString, stringToBrush } from "igniteui-react-core/ES2015/componentUtil";
/**
 * Series class which renders polygons as Paths based on lists of points in the ItemsSource.
*/
export class IgrScatterPolygonSeries extends IgrShapeSeriesBase {
    createImplementation() {
        return new ScatterPolygonSeries();
    }
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Returns whether the current series supports visual markers.
    */
    get hasMarkers() {
        return this.i.hasMarkers;
    }
    /**
     * The StyleSelector which is used to select a style for each Shape.
    */
    get shapeStyleSelector() {
        return this.i.m7;
    }
    set shapeStyleSelector(v) {
        this.i.m7 = v;
    }
    /**
     * The default style to apply to all Shapes in the series.
    */
    get shapeStyle() {
        if (this.i.n4 == null) {
            return null;
        }
        if (!this.i.n4.externalObject) {
            let e = new Style();
            e._implementation = this.i.n4;
            this.i.n4.externalObject = e;
        }
        return this.i.n4.externalObject;
    }
    set shapeStyle(v) {
        v == null ? this.i.n4 = null : this.i.n4 = v.i;
    }
    /**
     * Gets or sets the marker type for the current series object.
     * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
    */
    get markerType() {
        return this.i.m2;
    }
    set markerType(v) {
        this.i.m2 = ensureEnum(MarkerType_$type, v);
    }
    /**
     * Gets or sets the MarkerTemplate for the current series object.
    */
    get markerTemplate() {
        return this.i.nm;
    }
    set markerTemplate(v) {
        this.i.nm = v;
    }
    /**
     * Gets the effective marker template for the current series object.
    */
    get actualMarkerTemplate() {
        return this.i.nl;
    }
    set actualMarkerTemplate(v) {
        this.i.nl = v;
    }
    /**
     * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
    */
    get markerBrush() {
        return brushToString(this.i.n0);
    }
    set markerBrush(v) {
        this.i.n0 = stringToBrush(v);
    }
    /**
     * Gets the effective marker brush for the current series object.
    */
    get actualMarkerBrush() {
        return brushToString(this.i.ny);
    }
    set actualMarkerBrush(v) {
        this.i.ny = stringToBrush(v);
    }
    /**
     * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
    */
    get markerOutline() {
        return brushToString(this.i.n1);
    }
    set markerOutline(v) {
        this.i.n1 = stringToBrush(v);
    }
    /**
     * Gets the effective marker outline for the current series object.
    */
    get actualMarkerOutline() {
        return brushToString(this.i.nz);
    }
    set actualMarkerOutline(v) {
        this.i.nz = stringToBrush(v);
    }
    /**
     * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
    */
    get markerCollisionAvoidance() {
        return this.i.m1;
    }
    set markerCollisionAvoidance(v) {
        this.i.m1 = ensureEnum(CollisionAvoidanceType_$type, v);
    }
}

==> igniteui-react-charts-16.6.7.tgz: package/ES2015/igr-scatter-polygon-series.js <==
import { Style } from "igniteui-react-core/ES2015/igr-style";
import { MarkerType_$type } from "./MarkerType";
import { CollisionAvoidanceType_$type } from "./CollisionAvoidanceType";
import { IgrShapeSeriesBase } from "./igr-shape-series-base";
import { ScatterPolygonSeries } from "./ScatterPolygonSeries";
import { ensureEnum, brushToString, stringToBrush } from "igniteui-react-core/ES2015/componentUtil";
/**
 * Series class which renders polygons as Paths based on lists of points in the ItemsSource.
*/
export class IgrScatterPolygonSeries extends IgrShapeSeriesBase {
    createImplementation() {
        return new ScatterPolygonSeries();
    }
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Returns whether the current series supports visual markers.
    */
    get hasMarkers() {
        return this.i.hasMarkers;
    }
    /**
     * The StyleSelector which is used to select a style for each Shape.
    */
    get shapeStyleSelector() {
        return this.i.m9;
    }
    set shapeStyleSelector(v) {
        this.i.m9 = v;
    }
    /**
     * The default style to apply to all Shapes in the series.
    */
    get shapeStyle() {
        if (this.i.n6 == null) {
            return null;
        }
        if (!this.i.n6.externalObject) {
            let e = new Style();
            e._implementation = this.i.n6;
            this.i.n6.externalObject = e;
        }
        return this.i.n6.externalObject;
    }
    set shapeStyle(v) {
        v == null ? this.i.n6 = null : this.i.n6 = v.i;
    }
    /**
     * Gets or sets the marker type for the current series object.
     * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
    */
    get markerType() {
        return this.i.m4;
    }
    set markerType(v) {
        this.i.m4 = ensureEnum(MarkerType_$type, v);
    }
    /**
     * Gets or sets the MarkerTemplate for the current series object.
    */
    get markerTemplate() {
        return this.i.no;
    }
    set markerTemplate(v) {
        this.i.no = v;
    }
    /**
     * Gets the effective marker template for the current series object.
    */
    get actualMarkerTemplate() {
        return this.i.nn;
    }
    set actualMarkerTemplate(v) {
        this.i.nn = v;
    }
    /**
     * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
    */
    get markerBrush() {
        return brushToString(this.i.n2);
    }
    set markerBrush(v) {
        this.i.n2 = stringToBrush(v);
    }
    /**
     * Gets the effective marker brush for the current series object.
    */
    get actualMarkerBrush() {
        return brushToString(this.i.n0);
    }
    set actualMarkerBrush(v) {
        this.i.n0 = stringToBrush(v);
    }
    /**
     * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
    */
    get markerOutline() {
        return brushToString(this.i.n3);
    }
    set markerOutline(v) {
        this.i.n3 = stringToBrush(v);
    }
    /**
     * Gets the effective marker outline for the current series object.
    */
    get actualMarkerOutline() {
        return brushToString(this.i.n1);
    }
    set actualMarkerOutline(v) {
        this.i.n1 = stringToBrush(v);
    }
    /**
     * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
    */
    get markerCollisionAvoidance() {
        return this.i.m3;
    }
    set markerCollisionAvoidance(v) {
        this.i.m3 = ensureEnum(CollisionAvoidanceType_$type, v);
    }
}
